Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1140)

Unified Diff: talk/app/webrtc/webrtcsession.cc

Issue 1668493002: Replace uses of cricket::VideoRenderer by rtc::VideoSinkInterface. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « talk/app/webrtc/webrtcsession.h ('k') | talk/app/webrtc/webrtcsession_unittest.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: talk/app/webrtc/webrtcsession.cc
diff --git a/talk/app/webrtc/webrtcsession.cc b/talk/app/webrtc/webrtcsession.cc
index b1a7c21c7e23dc60092cd6cb790011e055f98488..7dd2a81ea168646ddf6efbe204ee0a807475880c 100644
--- a/talk/app/webrtc/webrtcsession.cc
+++ b/talk/app/webrtc/webrtcsession.cc
@@ -1329,19 +1329,20 @@ bool WebRtcSession::SetCaptureDevice(uint32_t ssrc,
return true;
}
-void WebRtcSession::SetVideoPlayout(uint32_t ssrc,
- bool enable,
- cricket::VideoRenderer* renderer) {
+void WebRtcSession::SetVideoPlayout(
+ uint32_t ssrc,
+ bool enable,
+ rtc::VideoSinkInterface<cricket::VideoFrame>* sink) {
ASSERT(signaling_thread()->IsCurrent());
if (!video_channel_) {
LOG(LS_WARNING) << "SetVideoPlayout: No video channel exists.";
return;
}
- if (!video_channel_->SetRenderer(ssrc, enable ? renderer : NULL)) {
- // Allow that SetRenderer fail if |renderer| is NULL but assert otherwise.
+ if (!video_channel_->SetSink(ssrc, enable ? sink : NULL)) {
+ // Allow that SetSink fail if |sink| is NULL but assert otherwise.
// This in the normal case when the underlying media channel has already
// been deleted.
- ASSERT(renderer == NULL);
+ ASSERT(sink == NULL);
}
}
« no previous file with comments | « talk/app/webrtc/webrtcsession.h ('k') | talk/app/webrtc/webrtcsession_unittest.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698